==> aws-sdk-2.323.0.jar: META-INF/resources/webjars/aws-sdk/2.323.0/SERVICES.md <==
The SDK currently supports the following services:

<p class="note"><strong>Note</strong>:
Although all services are supported in the browser version of the SDK,
not all of the services are available in the default hosted build (using the
script tag provided above). Instructions on how to build a
custom version of the SDK with individual services are provided
in the "<a href="http://docs.aws.amazon.com/sdk-for-javascript/v2/developer-guide/building-sdk-for-browsers.html">Building the SDK for Browsers</a>" section of the SDK Developer Guide.
</p>

Service Name | Class Name | API Version | Allows CORS |
------------ | ---------- | ----------- | ----------- |
AWS Certificate Manager | AWS.ACM | 2015-12-08 | :tada: |
Amazon API Gateway | AWS.APIGateway | 2015-07-09 | :tada: |
Application Auto Scaling | AWS.ApplicationAutoScaling | 2016-02-06 | :tada: |
Amazon AppStream | AWS.AppStream | 2016-12-01 |  |
Auto Scaling | AWS.AutoScaling | 2011-01-01 | :tada: |
AWS Batch | AWS.Batch | 2016-08-10 |  |
AWS Budgets | AWS.Budgets | 2016-10-20 |  |
Amazon CloudDirectory | AWS.CloudDirectory | 2017-01-11 |  |
Amazon CloudDirectory | AWS.CloudDirectory | 2016-05-10 |  |
AWS CloudFormation | AWS.CloudFormation | 2010-05-15 | :tada: |
Amazon CloudFront | AWS.CloudFront | 2017-10-30 | :tada: |
Amazon CloudFront | AWS.CloudFront | 2017-03-25 | :tada: |
Amazon CloudFront | AWS.CloudFront | 2016-11-25 | :tada: |
Amazon CloudHSM | AWS.CloudHSM | 2014-05-30 | :tada: |
Amazon CloudSearch | AWS.CloudSearch | 2013-01-01 |  |
Amazon CloudSearch | AWS.CloudSearch | 2011-02-01 |  |
Amazon CloudSearch Domain | AWS.CloudSearchDomain | 2013-01-01 |  |
AWS CloudTrail | AWS.CloudTrail | 2013-11-01 | :tada: |
Amazon CloudWatch | AWS.CloudWatch | 2010-08-01 | :tada: |
Amazon CloudWatch Events | AWS.CloudWatchEvents | 2015-10-07 | :tada: |
Amazon CloudWatch Logs | AWS.CloudWatchLogs | 2014-03-28 | :tada: |
AWS CodeBuild | AWS.CodeBuild | 2016-10-06 | :tada: |
AWS CodeCommit | AWS.CodeCommit | 2015-04-13 | :tada: |
AWS CodeDeploy | AWS.CodeDeploy | 2014-10-06 | :tada: |
AWS CodePipeline | AWS.CodePipeline | 2015-07-09 | :tada: |
Amazon Cognito Identity | AWS.CognitoIdentity | 2014-06-30 | :tada: |
Amazon Cognito Identity Provider | AWS.CognitoIdentityServiceProvider | 2016-04-18 | :tada: |
Amazon Cognito Sync | AWS.CognitoSync | 2014-06-30 | :tada: |
AWS Config | AWS.ConfigService | 2014-11-12 | :tada: |
AWS Cost and Usage Report Service | AWS.CUR | 2017-01-06 | :tada: |
AWS Data Pipeline | AWS.DataPipeline | 2012-10-29 |  |
AWS Device Farm | AWS.DeviceFarm | 2015-06-23 | :tada: |
AWS Direct Connect | AWS.DirectConnect | 2012-10-25 | :tada: |
AWS Directory Service | AWS.DirectoryService | 2015-04-16 |  |
AWS Application Discovery Service | AWS.Discovery | 2015-11-01 |  |
AWS Database Migration Service | AWS.DMS | 2016-01-01 |  |
Amazon DynamoDB | AWS.DynamoDB | 2012-08-10 | :tada: |
Amazon DynamoDB | AWS.DynamoDB | 2011-12-05 | :tada: |
Amazon DynamoDB Streams | AWS.DynamoDBStreams | 2012-08-10 | :tada: |
Amazon Elastic Compute Cloud | AWS.EC2 | 2016-11-15 | :tada: |
Amazon EC2 Container Registry | AWS.ECR | 2015-09-21 | :tada: |
Amazon EC2 Container Service | AWS.ECS | 2014-11-13 | :tada: |
Amazon Elastic File System | AWS.EFS | 2015-02-01 | :tada: |
Amazon ElastiCache | AWS.ElastiCache | 2015-02-02 | :tada: |
AWS Elastic Beanstalk | AWS.ElasticBeanstalk | 2010-12-01 | :tada: |
Elastic Load Balancing | AWS.ELB | 2012-06-01 | :tada: |
Elastic Load Balancing | AWS.ELBv2 | 2015-12-01 | :tada: |
Amazon Elastic MapReduce | AWS.EMR | 2009-03-31 | :tada: |
Amazon Elasticsearch Service | AWS.ES | 2015-01-01 |  |
Amazon Elastic Transcoder | AWS.ElasticTranscoder | 2012-09-25 | :tada: |
Amazon Kinesis Firehose | AWS.Firehose | 2015-08-04 | :tada: |
Amazon GameLift | AWS.GameLift | 2015-10-01 | :tada: |
Amazon Glacier | AWS.Glacier | 2012-06-01 |  |
AWS Health APIs and Notifications | AWS.Health | 2016-08-04 |  |
AWS Identity and Access Management | AWS.IAM | 2010-05-08 |  |
AWS Import/Export | AWS.ImportExport | 2010-06-01 |  |
Amazon Inspector | AWS.Inspector | 2016-02-16 | :tada: |
AWS IoT | AWS.Iot | 2015-05-28 | :tada: |
AWS IoT Data Plane | AWS.IotData | 2015-05-28 | :tada: |
Amazon Kinesis | AWS.Kinesis | 2013-12-02 | :tada: |
Amazon Kinesis Analytics | AWS.KinesisAnalytics | 2015-08-14 |  |
AWS Key Management Service | AWS.KMS | 2014-11-01 | :tada: |
AWS Lambda | AWS.Lambda | 2015-03-31 | :tada: |
AWS Lambda | AWS.Lambda | 2014-11-11 | :tada: |
Amazon Lex Runtime Service | AWS.LexRuntime | 2016-11-28 | :tada: |
Amazon Lightsail | AWS.Lightsail | 2016-11-28 |  |
Amazon Machine Learning | AWS.MachineLearning | 2014-12-12 | :tada: |
AWS Marketplace Commerce Analytics | AWS.MarketplaceCommerceAnalytics | 2015-07-01 | :tada: |
AWSMarketplace Metering | AWS.MarketplaceMetering | 2016-01-14 |  |
Amazon Mechanical Turk | AWS.MTurk | 2017-01-17 | :tada: |
Amazon Mobile Analytics | AWS.MobileAnalytics | 2014-06-05 | :tada: |
AWS OpsWorks | AWS.OpsWorks | 2013-02-18 | :tada: |
AWS OpsWorks for Chef Automate | AWS.OpsWorksCM | 2016-11-01 |  |
AWS Organizations | AWS.Organizations | 2016-11-28 |  |
Amazon Pinpoint | AWS.Pinpoint | 2016-12-01 |  |
Amazon Polly | AWS.Polly | 2016-06-10 | :tada: |
Amazon Relational Database Service | AWS.RDS | 2014-10-31 | :tada: |
Amazon Relational Database Service | AWS.RDS | 2014-09-01 | :tada: |
Amazon Relational Database Service | AWS.RDS | 2013-09-09 | :tada: |
Amazon Relational Database Service | AWS.RDS | 2013-02-12 | :tada: |
Amazon Relational Database Service | AWS.RDS | 2013-01-10 | :tada: |
Amazon Redshift | AWS.Redshift | 2012-12-01 | :tada: |
Amazon Rekognition | AWS.Rekognition | 2016-06-27 | :tada: |
AWS Resource Groups Tagging API | AWS.ResourceGroupsTaggingAPI | 2017-01-26 |  |
Amazon Route 53 | AWS.Route53 | 2013-04-01 | :tada: |
Amazon Route 53 Domains | AWS.Route53Domains | 2014-05-15 | :tada: |
Amazon Simple Storage Service | AWS.S3 | 2006-03-01 | :tada: |
AWS Service Catalog | AWS.ServiceCatalog | 2015-12-10 | :tada: |
Amazon Simple Email Service | AWS.SES | 2010-12-01 | :tada: |
AWS Shield | AWS.Shield | 2016-06-02 |  |
Amazon SimpleDB | AWS.SimpleDB | 2009-04-15 |  |
AWS Server Migration Service | AWS.SMS | 2016-10-24 |  |
Amazon Import/Export Snowball | AWS.Snowball | 2016-06-30 |  |
Amazon Simple Notification Service | AWS.SNS | 2010-03-31 | :tada: |
Amazon Simple Queue Service | AWS.SQS | 2012-11-05 | :tada: |
Amazon Simple Systems Manager (SSM) | AWS.SSM | 2014-11-06 | :tada: |
AWS Storage Gateway | AWS.StorageGateway | 2013-06-30 | :tada: |
AWS Step Functions | AWS.StepFunctions | 2016-11-23 |  |
AWS Security Token Service | AWS.STS | 2011-06-15 | :tada: |
AWS Support | AWS.Support | 2013-04-15 |  |
Amazon Simple Workflow Service | AWS.SWF | 2012-01-25 |  |
AWS X-Ray | AWS.XRay | 2016-04-12 |  |
AWS WAF | AWS.WAF | 2015-08-24 | :tada: |
AWS WAF Regional | AWS.WAFRegional | 2016-11-28 |  |
Amazon WorkDocs | AWS.WorkDocs | 2016-05-01 | :tada: |
Amazon WorkSpaces | AWS.WorkSpaces | 2015-04-08 |  |
AWS CodeStar | AWS.CodeStar | 2017-04-19 |  |
Amazon Lex Model Building Service | AWS.LexModelBuildingService | 2017-04-19 | :tada: |
AWS Marketplace Entitlement Service | AWS.MarketplaceEntitlementService | 2017-01-11 |  |
Amazon Athena | AWS.Athena | 2017-05-18 |  |
AWS Greengrass | AWS.Greengrass | 2017-06-07 |  |
Amazon DynamoDB Accelerator (DAX) | AWS.DAX | 2017-04-19 |  |
AWS Migration Hub | AWS.MigrationHub | 2017-05-31 |  |
AWS CloudHSM V2 | AWS.CloudHSMV2 | 2017-04-28 |  |
AWS Glue | AWS.Glue | 2017-03-31 |  |
AWS Mobile | AWS.Mobile | 2017-07-01 |  |
AWS Price List Service | AWS.Pricing | 2017-10-15 |  |
AWS Cost Explorer Service | AWS.CostExplorer | 2017-10-25 |  |
AWS Elemental MediaConvert | AWS.MediaConvert | 2017-08-29 |  |
AWS Elemental MediaLive | AWS.MediaLive | 2017-10-14 |  |
AWS Elemental MediaPackage | AWS.MediaPackage | 2017-10-12 |  |
AWS Elemental MediaStore | AWS.MediaStore | 2017-09-01 |  |
AWS Elemental MediaStore Data Plane | AWS.MediaStoreData | 2017-09-01 |  |
AWS AppSync | AWS.AppSync | 2017-07-25 |  |
Amazon GuardDuty | AWS.GuardDuty | 2017-11-28 |  |
AmazonMQ | AWS.MQ | 2017-11-27 |  |
Amazon Comprehend | AWS.Comprehend | 2017-11-27 |  |
AWS IoT Jobs Data Plane | AWS.IoTJobsDataPlane | 2017-09-29 |  |
Amazon Kinesis Video Streams Archived Media | AWS.KinesisVideoArchivedMedia | 2017-09-30 |  |
Amazon Kinesis Video Streams Media | AWS.KinesisVideoMedia | 2017-09-30 |  |
Amazon Kinesis Video Streams | AWS.KinesisVideo | 2017-09-30 |  |
Amazon SageMaker Runtime | AWS.SageMakerRuntime | 2017-05-13 |  |
Amazon SageMaker Service | AWS.SageMaker | 2017-07-24 |  |
Amazon Translate | AWS.Translate | 2017-07-01 |  |
AWS Resource Groups | AWS.ResourceGroups | 2017-11-27 |  |
Alexa For Business | AWS.AlexaForBusiness | 2017-11-09 |  |
AWS Cloud9 | AWS.Cloud9 | 2017-09-23 |  |
AWSServerlessApplicationRepository | AWS.ServerlessApplicationRepository | 2017-09-08 |  |
Amazon Route 53 Auto Naming | AWS.ServiceDiscovery | 2017-03-14 |  |
Amazon WorkMail | AWS.WorkMail | 2017-10-01 |  |
AWS Auto Scaling Plans | AWS.AutoScalingPlans | 2018-01-06 |  |
Amazon Transcribe Service | AWS.TranscribeService | 2017-10-26 |  |
Amazon Connect Service | AWS.Connect | 2017-08-08 |  |
AWS Certificate Manager Private Certificate Authority | AWS.ACMPCA | 2017-08-22 |  |
Firewall Management Service | AWS.FMS | 2018-01-01 |  |
AWS Secrets Manager | AWS.SecretsManager | 2017-10-17 | :tada: |
AWS IoT Analytics | AWS.IoTAnalytics | 2017-11-27 |  |
AWS IoT 1-Click Devices Service | AWS.IoT1ClickDevicesService | 2018-05-14 |  |
AWS IoT 1-Click Projects Service | AWS.IoT1ClickProjects | 2018-05-14 |  |
AWS Performance Insights | AWS.PI | 2018-02-27 |  |
Amazon Neptune | AWS.Neptune | 2014-10-31 |  |
AWS MediaTailor | AWS.MediaTailor | 2018-04-23 |  |
Amazon Elastic Container Service for Kubernetes | AWS.EKS | 2017-11-01 |  |
Amazon Macie | AWS.Macie | 2017-12-19 |  |

==> aws-sdk-2.1046.0.jar: META-INF/resources/webjars/aws-sdk/2.1046.0/SERVICES.md <==
The SDK currently supports the following services:

<p class="note"><strong>Note</strong>:
Although all services are supported in the browser version of the SDK,
not all of the services are available in the default hosted build (using the
script tag provided above). Instructions on how to build a
custom version of the SDK with individual services are provided
in the "<a href="http://docs.aws.amazon.com/sdk-for-javascript/v2/developer-guide/building-sdk-for-browsers.html">Building the SDK for Browsers</a>" section of the SDK Developer Guide.
</p>

Service Name | Class Name | API Version | Allows CORS |
------------ | ---------- | ----------- | ----------- |
AWS Certificate Manager | AWS.ACM | 2015-12-08 | :tada: |
Amazon API Gateway | AWS.APIGateway | 2015-07-09 | :tada: |
Application Auto Scaling | AWS.ApplicationAutoScaling | 2016-02-06 | :tada: |
Amazon AppStream | AWS.AppStream | 2016-12-01 |  |
Auto Scaling | AWS.AutoScaling | 2011-01-01 | :tada: |
AWS Batch | AWS.Batch | 2016-08-10 |  |
AWS Budgets | AWS.Budgets | 2016-10-20 |  |
Amazon CloudDirectory | AWS.CloudDirectory | 2017-01-11 |  |
Amazon CloudDirectory | AWS.CloudDirectory | 2016-05-10 |  |
AWS CloudFormation | AWS.CloudFormation | 2010-05-15 | :tada: |
Amazon CloudFront | AWS.CloudFront | 2018-11-05 | :tada: |
Amazon CloudFront | AWS.CloudFront | 2018-06-18 | :tada: |
Amazon CloudFront | AWS.CloudFront | 2017-10-30 | :tada: |
Amazon CloudFront | AWS.CloudFront | 2017-03-25 | :tada: |
Amazon CloudFront | AWS.CloudFront | 2016-11-25 | :tada: |
Amazon CloudHSM | AWS.CloudHSM | 2014-05-30 | :tada: |
Amazon CloudSearch | AWS.CloudSearch | 2013-01-01 |  |
Amazon CloudSearch | AWS.CloudSearch | 2011-02-01 |  |
Amazon CloudSearch Domain | AWS.CloudSearchDomain | 2013-01-01 |  |
AWS CloudTrail | AWS.CloudTrail | 2013-11-01 | :tada: |
Amazon CloudWatch | AWS.CloudWatch | 2010-08-01 | :tada: |
Amazon CloudWatch Events | AWS.CloudWatchEvents | 2015-10-07 | :tada: |
Amazon CloudWatch Logs | AWS.CloudWatchLogs | 2014-03-28 | :tada: |
AWS CodeBuild | AWS.CodeBuild | 2016-10-06 | :tada: |
AWS CodeCommit | AWS.CodeCommit | 2015-04-13 | :tada: |
AWS CodeDeploy | AWS.CodeDeploy | 2014-10-06 | :tada: |
AWS CodePipeline | AWS.CodePipeline | 2015-07-09 | :tada: |
Amazon Cognito Identity | AWS.CognitoIdentity | 2014-06-30 | :tada: |
Amazon Cognito Identity Provider | AWS.CognitoIdentityServiceProvider | 2016-04-18 | :tada: |
Amazon Cognito Sync | AWS.CognitoSync | 2014-06-30 | :tada: |
AWS Config | AWS.ConfigService | 2014-11-12 | :tada: |
AWS Cost and Usage Report Service | AWS.CUR | 2017-01-06 | :tada: |
AWS Data Pipeline | AWS.DataPipeline | 2012-10-29 |  |
AWS Device Farm | AWS.DeviceFarm | 2015-06-23 | :tada: |
AWS Direct Connect | AWS.DirectConnect | 2012-10-25 | :tada: |
AWS Directory Service | AWS.DirectoryService | 2015-04-16 |  |
AWS Application Discovery Service | AWS.Discovery | 2015-11-01 |  |
AWS Database Migration Service | AWS.DMS | 2016-01-01 |  |
Amazon DynamoDB | AWS.DynamoDB | 2012-08-10 | :tada: |
Amazon DynamoDB | AWS.DynamoDB | 2011-12-05 | :tada: |
Amazon DynamoDB Streams | AWS.DynamoDBStreams | 2012-08-10 | :tada: |
Amazon Elastic Compute Cloud | AWS.EC2 | 2016-11-15 | :tada: |
Amazon EC2 Container Registry | AWS.ECR | 2015-09-21 | :tada: |
Amazon EC2 Container Service | AWS.ECS | 2014-11-13 | :tada: |
Amazon Elastic File System | AWS.EFS | 2015-02-01 | :tada: |
Amazon ElastiCache | AWS.ElastiCache | 2015-02-02 | :tada: |
AWS Elastic Beanstalk | AWS.ElasticBeanstalk | 2010-12-01 | :tada: |
Elastic Load Balancing | AWS.ELB | 2012-06-01 | :tada: |
Elastic Load Balancing | AWS.ELBv2 | 2015-12-01 | :tada: |
Amazon Elastic MapReduce | AWS.EMR | 2009-03-31 | :tada: |
Amazon Elasticsearch Service | AWS.ES | 2015-01-01 |  |
Amazon Elastic Transcoder | AWS.ElasticTranscoder | 2012-09-25 | :tada: |
Amazon Kinesis Firehose | AWS.Firehose | 2015-08-04 | :tada: |
Amazon GameLift | AWS.GameLift | 2015-10-01 | :tada: |
Amazon Glacier | AWS.Glacier | 2012-06-01 |  |
AWS Health APIs and Notifications | AWS.Health | 2016-08-04 |  |
AWS Identity and Access Management | AWS.IAM | 2010-05-08 | :tada: |
AWS Import/Export | AWS.ImportExport | 2010-06-01 |  |
Amazon Inspector | AWS.Inspector | 2016-02-16 | :tada: |
AWS IoT | AWS.Iot | 2015-05-28 | :tada: |
AWS IoT Data Plane | AWS.IotData | 2015-05-28 | :tada: |
Amazon Kinesis | AWS.Kinesis | 2013-12-02 | :tada: |
Amazon Kinesis Analytics | AWS.KinesisAnalytics | 2015-08-14 |  |
AWS Key Management Service | AWS.KMS | 2014-11-01 | :tada: |
AWS Lambda | AWS.Lambda | 2015-03-31 | :tada: |
AWS Lambda | AWS.Lambda | 2014-11-11 | :tada: |
Amazon Lex Runtime Service | AWS.LexRuntime | 2016-11-28 | :tada: |
Amazon Lex Runtime V2 | AWS.LexRuntimeV2 | 2020-08-07 | :tada: |
Amazon Lightsail | AWS.Lightsail | 2016-11-28 |  |
Amazon Machine Learning | AWS.MachineLearning | 2014-12-12 | :tada: |
AWS Marketplace Commerce Analytics | AWS.MarketplaceCommerceAnalytics | 2015-07-01 | :tada: |
AWSMarketplace Metering | AWS.MarketplaceMetering | 2016-01-14 |  |
Amazon Mechanical Turk | AWS.MTurk | 2017-01-17 | :tada: |
Amazon Mobile Analytics | AWS.MobileAnalytics | 2014-06-05 | :tada: |
AWS OpsWorks | AWS.OpsWorks | 2013-02-18 | :tada: |
AWS OpsWorks for Chef Automate | AWS.OpsWorksCM | 2016-11-01 |  |
AWS Organizations | AWS.Organizations | 2016-11-28 |  |
Amazon Pinpoint | AWS.Pinpoint | 2016-12-01 |  |
Amazon Polly | AWS.Polly | 2016-06-10 | :tada: |
Amazon Relational Database Service | AWS.RDS | 2014-10-31 | :tada: |
Amazon Relational Database Service | AWS.RDS | 2014-09-01 | :tada: |
Amazon Relational Database Service | AWS.RDS | 2013-09-09 | :tada: |
Amazon Relational Database Service | AWS.RDS | 2013-02-12 | :tada: |
Amazon Relational Database Service | AWS.RDS | 2013-01-10 | :tada: |
Amazon Redshift | AWS.Redshift | 2012-12-01 | :tada: |
Amazon Rekognition | AWS.Rekognition | 2016-06-27 | :tada: |
AWS Resource Groups Tagging API | AWS.ResourceGroupsTaggingAPI | 2017-01-26 |  |
Amazon Route 53 | AWS.Route53 | 2013-04-01 | :tada: |
Amazon Route 53 Domains | AWS.Route53Domains | 2014-05-15 | :tada: |
Amazon Simple Storage Service | AWS.S3 | 2006-03-01 | :tada: |
AWS S3 Control | AWS.S3Control | 2018-08-20 |  |
AWS Service Catalog | AWS.ServiceCatalog | 2015-12-10 | :tada: |
Amazon Simple Email Service | AWS.SES | 2010-12-01 | :tada: |
AWS Shield | AWS.Shield | 2016-06-02 |  |
Amazon SimpleDB | AWS.SimpleDB | 2009-04-15 |  |
AWS Server Migration Service | AWS.SMS | 2016-10-24 |  |
Amazon Import/Export Snowball | AWS.Snowball | 2016-06-30 |  |
Amazon Simple Notification Service | AWS.SNS | 2010-03-31 | :tada: |
Amazon Simple Queue Service | AWS.SQS | 2012-11-05 | :tada: |
Amazon Simple Systems Manager (SSM) | AWS.SSM | 2014-11-06 | :tada: |
AWS Storage Gateway | AWS.StorageGateway | 2013-06-30 | :tada: |
AWS Step Functions | AWS.StepFunctions | 2016-11-23 |  |
AWS Security Token Service | AWS.STS | 2011-06-15 | :tada: |
AWS Support | AWS.Support | 2013-04-15 |  |
Amazon Simple Workflow Service | AWS.SWF | 2012-01-25 |  |
AWS X-Ray | AWS.XRay | 2016-04-12 | :tada: |
AWS WAF | AWS.WAF | 2015-08-24 | :tada: |
AWS WAF Regional | AWS.WAFRegional | 2016-11-28 |  |
Amazon WorkDocs | AWS.WorkDocs | 2016-05-01 | :tada: |
Amazon WorkSpaces | AWS.WorkSpaces | 2015-04-08 |  |
AWS CodeStar | AWS.CodeStar | 2017-04-19 |  |
Amazon Lex Model Building Service | AWS.LexModelBuildingService | 2017-04-19 | :tada: |
AWS Marketplace Entitlement Service | AWS.MarketplaceEntitlementService | 2017-01-11 |  |
Amazon Athena | AWS.Athena | 2017-05-18 |  |
AWS Greengrass | AWS.Greengrass | 2017-06-07 |  |
Amazon DynamoDB Accelerator (DAX) | AWS.DAX | 2017-04-19 |  |
AWS Migration Hub | AWS.MigrationHub | 2017-05-31 |  |
AWS CloudHSM V2 | AWS.CloudHSMV2 | 2017-04-28 |  |
AWS Glue | AWS.Glue | 2017-03-31 |  |
AWS Mobile | AWS.Mobile | 2017-07-01 |  |
AWS Price List Service | AWS.Pricing | 2017-10-15 | :tada: |
AWS Cost Explorer Service | AWS.CostExplorer | 2017-10-25 | :tada: |
AWS Elemental MediaConvert | AWS.MediaConvert | 2017-08-29 |  |
AWS Elemental MediaLive | AWS.MediaLive | 2017-10-14 |  |
AWS Elemental MediaPackage | AWS.MediaPackage | 2017-10-12 |  |
AWS Elemental MediaStore | AWS.MediaStore | 2017-09-01 |  |
AWS Elemental MediaStore Data Plane | AWS.MediaStoreData | 2017-09-01 | :tada: |
AWS AppSync | AWS.AppSync | 2017-07-25 |  |
Amazon GuardDuty | AWS.GuardDuty | 2017-11-28 |  |
AmazonMQ | AWS.MQ | 2017-11-27 |  |
Amazon Comprehend | AWS.Comprehend | 2017-11-27 | :tada: |
AWS IoT Jobs Data Plane | AWS.IoTJobsDataPlane | 2017-09-29 |  |
Amazon Kinesis Video Streams Archived Media | AWS.KinesisVideoArchivedMedia | 2017-09-30 | :tada: |
Amazon Kinesis Video Streams Media | AWS.KinesisVideoMedia | 2017-09-30 | :tada: |
Amazon Kinesis Video Streams | AWS.KinesisVideo | 2017-09-30 | :tada: |
Amazon SageMaker Runtime | AWS.SageMakerRuntime | 2017-05-13 |  |
Amazon SageMaker Service | AWS.SageMaker | 2017-07-24 |  |
Amazon Translate | AWS.Translate | 2017-07-01 | :tada: |
AWS Resource Groups | AWS.ResourceGroups | 2017-11-27 | :tada: |
Alexa For Business | AWS.AlexaForBusiness | 2017-11-09 |  |
AWS Cloud9 | AWS.Cloud9 | 2017-09-23 |  |
AWSServerlessApplicationRepository | AWS.ServerlessApplicationRepository | 2017-09-08 |  |
AWS Cloud Map | AWS.ServiceDiscovery | 2017-03-14 |  |
Amazon WorkMail | AWS.WorkMail | 2017-10-01 |  |
AWS Auto Scaling Plans | AWS.AutoScalingPlans | 2018-01-06 |  |
Amazon Transcribe Service | AWS.TranscribeService | 2017-10-26 |  |
Amazon Connect Service | AWS.Connect | 2017-08-08 | :tada: |
AWS Certificate Manager Private Certificate Authority | AWS.ACMPCA | 2017-08-22 |  |
Firewall Management Service | AWS.FMS | 2018-01-01 |  |
AWS Secrets Manager | AWS.SecretsManager | 2017-10-17 | :tada: |
AWS IoT Analytics | AWS.IoTAnalytics | 2017-11-27 | :tada: |
AWS IoT 1-Click Devices Service | AWS.IoT1ClickDevicesService | 2018-05-14 |  |
AWS IoT 1-Click Projects Service | AWS.IoT1ClickProjects | 2018-05-14 |  |
AWS Performance Insights | AWS.PI | 2018-02-27 |  |
Amazon Neptune | AWS.Neptune | 2014-10-31 |  |
AWS MediaTailor | AWS.MediaTailor | 2018-04-23 |  |
Amazon Elastic Container Service for Kubernetes | AWS.EKS | 2017-11-01 |  |
Amazon Macie | AWS.Macie | 2017-12-19 |  |
Amazon Data Lifecycle Manager | AWS.DLM | 2018-01-12 |  |
AWS Signer | AWS.Signer | 2017-08-25 |  |
Amazon Chime | AWS.Chime | 2018-05-01 |  |
Amazon Pinpoint Email Service | AWS.PinpointEmail | 2018-07-26 |  |
AWS Resource Access Manager | AWS.RAM | 2018-01-04 |  |
Amazon Route 53 Resolver | AWS.Route53Resolver | 2018-04-01 |  |
Amazon Pinpoint SMS and Voice Service | AWS.PinpointSMSVoice | 2018-09-05 |  |
Amazon QuickSight | AWS.QuickSight | 2018-04-01 |  |
AWS RDS DataService | AWS.RDSDataService | 2018-08-01 |  |
AWS Amplify | AWS.Amplify | 2017-07-25 |  |
AWS DataSync | AWS.DataSync | 2018-11-09 |  |
AWS RoboMaker | AWS.RoboMaker | 2018-06-29 |  |
AWS Transfer for SFTP | AWS.Transfer | 2018-11-05 |  |
AWS Global Accelerator | AWS.GlobalAccelerator | 2018-08-08 |  |
AWS Comprehend Medical | AWS.ComprehendMedical | 2018-10-30 | :tada: |
Amazon Kinesis Analytics | AWS.KinesisAnalyticsV2 | 2018-05-23 |  |
AWS MediaConnect | AWS.MediaConnect | 2018-11-14 |  |
Amazon FSx | AWS.FSx | 2018-03-01 |  |
AWS SecurityHub | AWS.SecurityHub | 2018-10-26 |  |
AWS App Mesh | AWS.AppMesh | 2019-01-25 |  |
AWS App Mesh | AWS.AppMesh | 2018-10-01 |  |
AWS License Manager | AWS.LicenseManager | 2018-08-01 |  |
Managed Streaming for Kafka | AWS.Kafka | 2018-11-14 |  |
AmazonApiGatewayManagementApi | AWS.ApiGatewayManagementApi | 2018-11-29 |  |
AmazonApiGatewayV2 | AWS.ApiGatewayV2 | 2018-11-29 |  |
Amazon DocumentDB with MongoDB compatibility | AWS.DocDB | 2014-10-31 |  |
AWS Backup | AWS.Backup | 2018-11-15 |  |
Amazon WorkLink | AWS.WorkLink | 2018-09-25 |  |
Amazon Textract | AWS.Textract | 2018-06-27 |  |
